==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/ast.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Comentarios",
    "Unknown user" : "Usuariu desconocíu",
    "New comment …" : "Comentariu nuevu...",
    "Delete comment" : "Desaniciar comentariu",
    "Post" : "Espublizar",
    "Cancel" : "Encaboxar",
    "Edit comment" : "Editar comentariu",
    "[Deleted user]" : "[Usuariu desaniciáu]",
    "No comments yet, start the conversation!" : "Entá nun hai comentarios. ¡Entama una conversación!",
    "More comments …" : "Más comentarios...",
    "Save" : "Guardar",
    "Allowed characters {count} of {max}" : "{count} caráuteres almitíos de {max}",
    "Error occurred while retrieving comment with id {id}" : "Asocedió un fallu entrín se recibía'l comentariu cola ID {id}",
    "Error occurred while updating comment with id {id}" : "Asocedió un fallu entrín s'anovaba'l comentariu cola ID {id}",
    "Error occurred while posting comment" : "Asocedieron fallos entrín s'espublizaba'l comentariu",
    "_%n unread comment_::_%n unread comments_" : ["%n comentariu ensin lleer","%n comentarios ensin lleer"],
    "Comment" : "Comentariu",
    "You commented" : "Comentesti",
    "%1$s commented" : "%1$s comentó",
    "{author} commented" : "{author} comentó",
    "You commented on %1$s" : "Comentesti en %1$s",
    "You commented on {file}" : "Comentesti en {file}",
    "%1$s commented on %2$s" : "%1$s comentó en %2$s",
    "{author} commented on {file}" : "{autor} comentó en {ficheru}",
    "<strong>Comments</strong> for files" : "<strong>Comentarios</strong> pa ficheros",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Un usuariu (agora) desaniciáu mentóte nun comentariu de «%s»",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Un usuariu (agora) desaniciáu mentóte nun comentariu de «{file}»",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s mentóte nun comentariu de «%2$s»",
    "{user} mentioned you in a comment on “{file}”" : "{user} mentóte nun comentariu de «{file}»"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/ast.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Comentarios",
    "Unknown user" : "Usuariu desconocíu",
    "New comment …" : "Comentariu nuevu...",
    "Delete comment" : "Desaniciar comentariu",
    "Post" : "Espublizar",
    "Cancel" : "Encaboxar",
    "Edit comment" : "Editar comentariu",
    "[Deleted user]" : "[Usuariu desaniciáu]",
    "No comments yet, start the conversation!" : "Entá nun hai comentarios. ¡Entama una conversación!",
    "More comments …" : "Más comentarios...",
    "Save" : "Guardar",
    "Allowed characters {count} of {max}" : "{count} caráuteres almitíos de {max}",
    "Error occurred while retrieving comment with id {id}" : "Asocedió un fallu entrín se recibía'l comentariu cola ID {id}",
    "Error occurred while updating comment with id {id}" : "Asocedió un fallu entrín s'anovaba'l comentariu cola ID {id}",
    "Error occurred while posting comment" : "Asocedieron fallos entrín s'espublizaba'l comentariu",
    "_%n unread comment_::_%n unread comments_" : ["%n comentariu ensin lleer","%n comentarios ensin lleer"],
    "Comment" : "Comentariu",
    "You commented" : "Comentesti",
    "%1$s commented" : "%1$s comentó",
    "{author} commented" : "{author} comentó",
    "You commented on %1$s" : "Comentesti en %1$s",
    "You commented on {file}" : "Comentesti en {file}",
    "%1$s commented on %2$s" : "%1$s comentó en %2$s",
    "{author} commented on {file}" : "{autor} comentó en {ficheru}",
    "<strong>Comments</strong> for files" : "<strong>Comentarios</strong> pa ficheros",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s mentóte nun comentariu de «%2$s»",
    "{user} mentioned you in a comment on “{file}”" : "{user} mentóte nun comentariu de «{file}»",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Un usuariu (agora) desaniciáu mentóte nun comentariu de «%s»",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Un usuariu (agora) desaniciáu mentóte nun comentariu de «{file}»"
},
"nplurals=2; plural=(n != 1);");
